import express from "express";
import {
  registerUser,
  loginUser,
  logout,
  forgotPassword,
  resetPassword,
  getUserDetails,
  updatePassword,
  updateProfile,
  getSingleUser,
  getAllUser,
  getUserOrderForAdmin,
  getAllEmployee,
  deleteEmployeeById,
  updateEmployeeById,
} from "./userController.js";
import { isAuthenticatedUser, authorizeRoles } from "../../middlewares/auth.js";

const router = express.Router();

router.route("/user/register").post(registerUser);

router.route("/user/login").post(loginUser);

router.route("/user/password/forgot").post(forgotPassword);

router.route("/user/password/reset/:token").put(resetPassword);

router.route("/user/logout").get(logout);

router.route("/user/details").get(isAuthenticatedUser, getUserDetails);

router
  .route("/admin/users")
  .get(isAuthenticatedUser, authorizeRoles("admin", "Employee"), getAllUser);
router
  .route("/admin/delete-employee/:id")
  .delete(
    isAuthenticatedUser,
    authorizeRoles("admin", "Employee"),
    deleteEmployeeById
  );
router
  .route("/admin/employee")
  .get(
    isAuthenticatedUser,
    authorizeRoles("admin", "Employee"),
    getAllEmployee
  );
router
  .route("/admin/update-employee/:id")
  .put(
    isAuthenticatedUser,
    authorizeRoles("admin", "Employee"),
    updateEmployeeById
  );
router
  .route("/admin/users/orders/:id")
  .get(
    isAuthenticatedUser,
    authorizeRoles("admin", "Employee"),
    getUserOrderForAdmin
  );

router
  .route("/admin/user/:id")
  .get(isAuthenticatedUser, authorizeRoles("admin", "Employee"), getSingleUser);

router.route("/user/password/update").put(isAuthenticatedUser, updatePassword);

router.route("/user/update/profile").put(isAuthenticatedUser, updateProfile);

export default router;
